@@ -26,14 +26,15 @@ SOFTWARE.
 """
 
 
-from pathlib import Path
 from urllib.request import Request
 from urllib.request import urlopen
 from urllib.parse import urlsplit
 
+import argparse
 import errno
 import glob
 import os
+import pathlib
 import shlex
 import subprocess
 import sys
@@ -83,7 +84,7 @@ def glob_multiple_extensions(extensions):
     return files_globbed
 
 
-def simple_extract(archive, archive_cmd):
+def simple_extract(archive, archive_cmd, noclobber=False):
     """Extract an archive using external tools."""
 
     uses_stdin = archive_cmd.uses_stdin
@@ -97,11 +98,15 @@ def simple_extract(archive, archive_cmd):
     pipe_cmd = shlex.split(archive_cmd.pipe_cmd)
 
     # Split archive name separating extensions
-    path = Path(archive)
-    if not uses_stdout:
-        target, _ = os.path.split(path.stem)
-    else:
-        target = path.stem
+    target_path = pathlib.PurePath(archive)
+    for suffix in target_path.suffixes:
+        target, _ = os.path.split(target_path)
+
+    print(f"Target: {target}")
+
+    if os.path.exists(target) and noclobber:
+        print(f"Target: {target} already exists not overwriting...")
+        return
 
     # Extract archive
     with open(archive) as fin:
@@ -141,17 +146,26 @@ def should_fetch_url(url, fp):
     return True
 
 
-def fetch_archive(url):
+def fetch_archive(url, silent_download=False):
     """Download an archive for extraction."""
 
     _, target = os.path.split(url)
 
     if command_exists("curl"):
-        fetch_cmd = shlex.split("curl -L -s -o -" + " " + url)
+        if silent_download:
+            fetch_cmd = shlex.split("curl -L -s -o -" + " " + url)
+        else:
+            fetch_cmd = shlex.split("curl -L -o -" + " " + url)
     elif command_exists("wget"):
-        fetch_cmd = shlex.split("wget -q -O -" + " " + url)
+        if silent_download:
+            fetch_cmd = shlex.split("wget -q -O -" + " " + url)
+        else:
+            fetch_cmd = shlex.split("wget -O -" + " " + url)
     elif command_exists("fetch"):
-        fetch_cmd = shlex.split("fetch -q -o -" + " " + url)
+        if silent_download:
+            fetch_cmd = shlex.split("fetch -q -o -" + " " + url)
+        else:
+            fetch_cmd = shlex.split("fetch -o -" + " " + url)
     else:
         print("Error: no suitable download program found.")
         return False
@@ -183,8 +197,27 @@ def extract_urls(args):
 def main():
     """Main function."""
 
+    parser = argparse.ArgumentParser(
+        description="A small command line utility to extract compressed archives.",
+        epilog="Copyright (c) 2021 Michael Berry",
+    )
+    parser.add_argument(
+        "--noclobber",
+        action="store_true",
+        help="Don't overwrite existing files",
+        dest="noclobber",
+    )
+    parser.add_argument(
+        "--silent_download",
+        action="store_true",
+        help="Don't show archive download progress",
+        dest="silent_download",
+    )
+    parser.add_argument("ARCHIVES", nargs="*")
+    parsed = parser.parse_args()
+
     working_dir = os.getcwd()
-    args = sys.argv[1:]
+    args = [x for x in parsed.ARCHIVES]
     files_globbed = []
     commands = []
 
@@ -195,7 +228,7 @@ def main():
 
     url_archives = extract_urls(args)
     for url in url_archives:
-        target = fetch_archive(url)
+        target = fetch_archive(url, silent_download=parsed.silent_download)
         if not target:
             continue
         archives.append(target)
@@ -282,6 +315,7 @@ def main():
         print(f"Files to extract: {files_globbed}")
     else:
         print("Nothing to do.")
+        print("Try passing --help as an argument for more information.")
         sys.exit(0)
 
     os.chdir(working_dir)
@@ -292,7 +326,7 @@ def main():
             print(f"Error: {root_cmd} does not exist...not extracting {archive}.")
             continue
         print(f"Extracting file {archive}")
-        simple_extract(archive, archive_cmd)
+        simple_extract(archive, archive_cmd, noclobber=parsed.noclobber)
 
 
 if __name__ == "__main__":
